@@ -1,7 +1,7 @@
 #!/bin/sh
 echo 'name: murmur-hash
-version: 0.1.0.5
-id: murmur-hash-0.1.0.5-16674e6b7d30714e5f6d0df21bd68c32
+version: 0.1.0.6
+id: murmur-hash-0.1.0.6-4ff91c2fc4da0b0998da1054b92f39ed
 
 license: BSD3
 copyright:
@@ -23,20 +23,20 @@ exposed: True
 exposed-modules: Data.Digest.Murmur32 Data.Digest.Murmur64
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.5
-library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.5
-hs-libraries: HSmurmur-hash-0.1.0.5
+import-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.6
+library-dirs: /usr/local/lib/ghc/murmur-hash-0.1.0.6
+hs-libraries: HSmurmur-hash-0.1.0.6
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         bytestring-0.9.2.1-4f95f32adc23f1bc25c472a646e99581
+depends: base-4.6.0.1-d435272bc8de1d17f3a0aacfbd562dbe
+         bytestring-0.10.0.2-f858e0cb19bca2e9549882fc8424f656
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.5/html/murmur-hash.haddock
-haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.5/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-murmur-hash-0.1.0.6/html/murmur-hash.haddock
+haddock-html: /usr/local/share/doc/hs-murmur-hash-0.1.0.6/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
